
(function IkasRoasberryApp() {
    const EVENT_HANDLER_ID = 'berry_' + Date.now();

    function init() {
        try {
            window.IkasEvents &&
                window.IkasEvents.subscribe({
                    id: EVENT_HANDLER_ID,
                    callback: onIkasEvent,
                });

            var _paq = (window._paq = window._paq || []);

            _paq.push(['trackPageView']);
            _paq.push(['enableLinkTracking']);
            (function () {
                var u = 'https://sweetsipscoffee.matomo.cloud/';
                _paq.push(['setTrackerUrl', u + 'matomo.php']);
                _paq.push(['setSiteId', '55']);
                var d = document,
                    g = d.createElement('script'),
                    s = d.getElementsByTagName('script')[0];
                g.async = true;
                g.src =
                    'https://cdn.matomo.cloud/sweetsipscoffee.matomo.cloud/matomo.js';
                s.parentNode.insertBefore(g, s);
            })();
        } catch (err) {
            console.error(err);
        }
    }

    function onIkasEvent(event) {
        const { type, data } = event;
        console.log('Event', type, typeof type, data, typeof data, event);

        try {
            switch (type) {
                case 'PRODUCT_VIEW':
                    const product = data.productDetail;
                    const productPrice =
                        product.variant.prices && product.variant.prices.length
                            ? product.variant.prices[0].sellPrice
                            : product.finalPrice;
                    window._paq.push([
                        'setEcommerceView',
                        { productSKU: product.id },
                        { productName: product.name },
                        { categoryName: 'kAYAK' },
                        { price: productPrice },
                    ]);
                    break;
                case 'ADD_TO_CART':
                    const item = data.item;
                    const cart = data.cart;
                    const price =
                        item.variant.prices && item.variant.prices.length
                            ? item.variant.prices[0].sellPrice
                            : item.finalPrice;

                    window._paq.push([
                        'addEcommerceItem',
                        { productSKU: 'Test Product' },
                        { productName: 'product.name' },
                        { categoryName: 'categories' },
                        { price: price },
                    ]);
                    window._paq.push(['trackEcommerceCartUpdate', cart.totalFinalPrice]);
                    break;
                case 'VIEW_CART':
                    const items = data.cart.items;
                    if (!items.length) return null;
                    items.forEach((item) => {
                        window._paq.push([
                            'addEcommerceItem',
                            { productSKU: item.variant.id },
                            { productName: item.variant.name },
                            { categoryName: 'Tests Category' },
                            { price: item.finalPrice },
                        ]);
                    });
                    const totalPrice = data.cart.totalPrice;
                    window._paq.push(['trackEcommerceCartUpdate', totalPrice]);
                    break;
                case 'COMPLETE_CHECKOUT':
                    const checkout = data.checkout;
                    if (!checkout.items.length) return null;
                    window._paq.push(['setExcludedQueryParams', ['/_[a-z_0-9]*/']]);

                    for (let i = 0; i < checkout.items.length; i++) {
                        window._paq.push([
                            'addEcommerceItem',
                            { productSKU: checkout.items[i].variant.id },
                            { productName: checkout.items[i].variant.name },
                            { categoryName: 'Tests Category' },
                            { price: checkout.items[i].finalPrice },
                        ]);
                    }

                    window._paq.push([
                        'trackEcommerceOrder',
                        checkout.id,
                        checkout.totalFinalPrice,
                    ]);
                    break;
                default:
                    break;
            }
        } catch (err) {
            console.error(err);
        }
    }

    init();
})();
